==> pegasus-merchandise-api-1.3.1-sources.jar: com/thebeastshop/pegasus/merchandise/IService/IInterestFreeService.java <==
package com.thebeastshop.pegasus.merchandise.IService;

import java.util.List;

import com.thebeastshop.scm.cond.InterestFreeCond;
import com.thebeastshop.scm.po.InterestFreeProvide;
import com.thebeastshop.scm.vo.interest.InterestFreeProductExcelVO;
import com.thebeastshop.scm.vo.interest.InterestFreeProvideVO;
import com.thebeastshop.scm.vo.interest.InterestFreeUseVO;
import com.thebeastshop.scm.vo.interest.InterestFreeVO;

/**
 * 免邮权益接口
 * @param <JsonResult>
 * @Class Name IInterestFreeService
 * @Author Xiang.Gao
 * @Create In 2017-3-16
 */
public interface IInterestFreeService {

	/**
	 * 保存权益
	 * @Methods Name save
	 * @Create In 2017-3-16 By Xiang.Gao
	 */
	public void save(InterestFreeVO interestFreeVO);
	
	/**
	 * 查询权益
	 * @Methods Name queryList
	 * @Create In 2017-3-16 By Xiang.Gao
	 */
	public List<InterestFreeVO> queryList(InterestFreeCond cond);
	
	/**
	 * 获取单条权益
	 * @Methods Name queryByInterestFreeId
	 * @Create In 2017-3-16 By Xiang.Gao
	 */
	public InterestFreeVO queryByInterestFreeId(Integer interestFreeId);
	
	/**
	 * 权益发放记录
	 * @Methods Name queryInterestFreeProvide
	 * @Create In 2017-3-16 By Xiang.Gao
	 */
	public List<InterestFreeProvideVO> selectProvideRecord(InterestFreeCond cond);
	
	/**
	 * 查询适用商品
	 * @Methods Name selectProducts
	 * @Create In 2017-3-28 By Xiang.Gao
	 */
	public List<InterestFreeProductExcelVO> selectProducts(Integer interestFreeId);
	
	
	/**----------------以下接口提供给外部调用           --------------------------*/
	
	/**
	 * 免邮权益发放
	 * @Methods Name InterestFreeProvide
	 * @Create In 2017-3-20 By Xiang.Gao
	 */
	public InterestFreeProvide interestFreeProvide(Integer memberId,Integer interestFreeId,String provideChannel);
	
	/**
	 * 获取可用免邮权益
	 * @Methods Name getCanUseInterestFree
	 * @Create In 2017-3-20 By Xiang.Gao
	 */
	public InterestFreeVO getCanUseInterestFree(InterestFreeUseVO interestFreeUseVO);
	
	/**
	 * 获取免邮权益详情
	 * @Methods Name queryInterestFreeInfo
	 * @Create In 2017-4-19 By Xiang.Gao
	 */
	public InterestFreeVO queryInterestFreeInfo(Integer provideId);
	
	/**
	 * 使用免邮权益
	 * @Methods Name interestFreeCash
	 * @Create In 2017-3-20 By Xiang.Gao
	 */
	public void interestFreeCash(InterestFreeUseVO interestFreeUseVO);
	
	/**
	 * 返还免邮权益
	 * @Methods Name interestFreeBack
	 * @Create In 2017-3-24 By Xiang.Gao
	 */
	public void interestFreeBack(InterestFreeUseVO interestFreeUseVO);
	
	/**
	 * 根据天数获取快要的免邮权益
	 * @Methods Name getPreExpiration
	 * @Create In 2017-4-20 By Xiang.Gao
	 */
	public List<InterestFreeVO> getPreExpiration(Integer day);
	
}

==> pegasus-merchandise-api-2.9.3-sources.jar: com/thebeastshop/pegasus/merchandise/IService/IInterestFreeService.java <==
package com.thebeastshop.pegasus.merchandise.IService;

import java.util.List;

import com.thebeastshop.scm.cond.InterestFreeCond;
import com.thebeastshop.scm.po.InterestFreeProvide;
import com.thebeastshop.scm.vo.interest.InterestFreeProductExcelVO;
import com.thebeastshop.scm.vo.interest.InterestFreeProvideVO;
import com.thebeastshop.scm.vo.interest.InterestFreeUseVO;
import com.thebeastshop.scm.vo.interest.InterestFreeVO;

/**
 * 免邮权益接口
 * @param <JsonResult>
 * @Class Name IInterestFreeService
 * @Author Xiang.Gao
 * @Create In 2017-3-16
 */
public interface IInterestFreeService {

	/**
	 * 保存权益
	 * @Methods Name save
	 * @Create In 2017-3-16 By Xiang.Gao
	 */
	public void save(InterestFreeVO interestFreeVO);
	
	/**
	 * 查询权益
	 * @Methods Name queryList
	 * @Create In 2017-3-16 By Xiang.Gao
	 */
	public List<InterestFreeVO> queryList(InterestFreeCond cond);
	
	/**
	 * 获取单条权益
	 * @Methods Name queryByInterestFreeId
	 * @Create In 2017-3-16 By Xiang.Gao
	 */
	public InterestFreeVO queryByInterestFreeId(Integer interestFreeId);
	
	/**
	 * 权益发放记录
	 * @Methods Name queryInterestFreeProvide
	 * @Create In 2017-3-16 By Xiang.Gao
	 */
	public List<InterestFreeProvideVO> selectProvideRecord(InterestFreeCond cond);
	
	/**
	 * 查询适用商品
	 * @Methods Name selectProducts
	 * @Create In 2017-3-28 By Xiang.Gao
	 */
	public List<InterestFreeProductExcelVO> selectProducts(Integer interestFreeId);
	
	
	/**----------------以下接口提供给外部调用           --------------------------*/
	
	/**
	 * 免邮权益发放
	 * @Methods Name InterestFreeProvide
	 * @Create In 2017-3-20 By Xiang.Gao
	 */
	public InterestFreeProvide interestFreeProvide(Integer memberId,Integer interestFreeId,String provideChannel);
	
	/**
	 * 获取可用免邮权益
	 * @Methods Name getCanUseInterestFree
	 * @Create In 2017-3-20 By Xiang.Gao
	 */
	public InterestFreeVO getCanUseInterestFree(InterestFreeUseVO interestFreeUseVO);
	
	/**
	 * 获取免邮权益详情
	 * @Methods Name queryInterestFreeInfo
	 * @Create In 2017-4-19 By Xiang.Gao
	 */
	public InterestFreeVO queryInterestFreeInfo(Integer provideId);
	
	/**
	 * 使用免邮权益
	 * @Methods Name interestFreeCash
	 * @Create In 2017-3-20 By Xiang.Gao
	 */
	public void interestFreeCash(InterestFreeUseVO interestFreeUseVO);
	
	/**
	 * 返还免邮权益
	 * @Methods Name interestFreeBack
	 * @Create In 2017-3-24 By Xiang.Gao
	 */
	public void interestFreeBack(InterestFreeUseVO interestFreeUseVO);
	
	/**
	 * 根据天数获取快要的免邮权益
	 * @Methods Name getPreExpiration
	 * @Create In 2017-4-20 By Xiang.Gao
	 */
	public List<InterestFreeVO> getPreExpiration(Integer day);
	
	/**
	 * 修改免邮权益所属用户
	 * @Methods Name changeMember
	 * @Create In 2017-9-1 By Xiang.Gao
	 * @param sourceMemberId
	 * @param targetMemberId
	 * @return int
	 */
	public int changeMember(Integer sourceMemberId, Integer targetMemberId);
	
}
